@@ -18,7 +18,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 #------------------------------------------------------------------------
 
@@ -30,6 +30,7 @@ has repository_url => (
     coerce    => 1,
 );
 
+#------------------------------------------------------------------------
 
 
 has user_agent => (
@@ -38,6 +39,8 @@ has user_agent => (
    default     => sub { LWP::UserAgent->new() },
 );
 
+#------------------------------------------------------------------------
+
 
 has cache_dir => (
    is         => 'ro',
@@ -46,6 +49,7 @@ has cache_dir => (
    coerce     => 1,
 );
 
+#------------------------------------------------------------------------
 
 
 has force => (
@@ -54,6 +58,8 @@ has force => (
    default    => 0,
 );
 
+#------------------------------------------------------------------------
+
 
 has index_file => (
     is         => 'ro',
@@ -62,6 +68,8 @@ has index_file => (
     lazy_build => 1,
 );
 
+#------------------------------------------------------------------------
+
 
 has distributions => (
    is         => 'ro',
@@ -72,6 +80,9 @@ has distributions => (
 );
 
 
+#------------------------------------------------------------------------
+
+
 
 has packages => (
    is         => 'ro',
@@ -82,6 +93,9 @@ has packages => (
 );
 
 
+#------------------------------------------------------------------------
+
+
 has _data => (
     is         => 'ro',
     isa        => 'HashRef',
@@ -119,10 +133,10 @@ sub _build__data {
 
     my $file = $self->index_file();
     open my $fh, '<:gzip', $file or croak "Failed to open index file $file: $!";
-    my $data = $self->__read_index($fh);
+    my $index_data = $self->__read_index($fh);
     close $fh;
 
-    return $data;
+    return $index_data;
 }
 
 #------------------------------------------------------------------------------
@@ -194,7 +208,7 @@ Package::Locator::Index - The package index of a repository
 
 =head1 VERSION
 
-version 0.004
+version 0.006
 
 =head1 SYNOPSIS
 
